@@ -28,7 +28,7 @@ use Class::MOP;
 
 use Scalar::Util qw(refaddr);
 
-our $VERSION = '1.99_05';
+our $VERSION = '1.99_06';
 
 coerce 'Chart::Clicker::Renderer'
     => from 'Str'
@@ -86,7 +86,8 @@ has 'driver' => (
     is => 'rw',
     does => 'Graphics::Primitive::Driver',
     default => sub { Graphics::Primitive::Driver::Cairo->new },
-    handles => [ qw(data write) ]
+    handles => [ qw(data write) ],
+    lazy => 1
 );
 has 'grid' => (
     is => 'rw',
@@ -284,6 +285,31 @@ __END__
 
 Chart::Clicker - Powerful, extensible charting.
 
+=head1 SYNOPSIS
+
+  use Chart::Clicker
+  use Chart::Clicker::Data::Series;
+  use Chart::Clicker::Data::DataSet;
+
+  my $cc = Chart::Clicker->new;
+
+  my $series = Chart::Clicker::Data::Series->new(
+    keys    => [ 1, 2, 3, 4, 5, 6, 7, 8, 9, 10 ],
+    values  => [ 42, 25, 86, 23, 2, 19, 103, 12, 54, 9 ],
+  );
+
+  my $series2 = Chart::Clicker::Data::Series->new(
+    keys    => [ 1, 2, 3, 4, 5, 6, 7, 8, 9, 10 ],
+    values  => [ 67, 15, 6, 90, 11, 45, 83, 11, 9, 101 ],
+  );
+
+  my $ds = Chart::Clicker::Data::DataSet->new(series => [ $series, $series2 ]);
+ 
+  $cc->add_to_datasets($ds);
+
+  $cc->draw;
+  $cc->write('foo.png')
+
 =head1 DESCRIPTION
 
 Chart::Clicker aims to be a powerful, extensible charting package that creates
@@ -334,33 +360,6 @@ renderer.
 
 Clicker supports PNG, SVG, PDF and PostScript output.
 
-=head1 SYNOPSIS
-
-use Chart::Clicker
-use Chart::Clicker::Data::Series;
-use Chart::Clicker::Data::DataSet;
-
-my $cc = Chart::Clicker->new;
-
-my $series = Chart::Clicker::Data::Series->new(
-    keys    => [ 1, 2, 3, 4, 5, 6, 7, 8, 9, 10 ],
-    values  => [ 42, 25, 86, 23, 2, 19, 103, 12, 54, 9 ],
-);
-
-my $series2 = Chart::Clicker::Data::Series->new(
-    keys    => [ 1, 2, 3, 4, 5, 6, 7, 8, 9, 10 ],
-    values  => [ 67, 15, 6, 90, 11, 45, 83, 11, 9, 101 ],
-);
-
-my $ds = Chart::Clicker::Data::DataSet->new(series => [ $series, $series2 ]);
-
-$cc->add_to_datasets($ds);
-
-$cc->draw;
-$cc->write('foo.png')
-
-=cut
-
 =head1 METHODS
 
 =head2 Constructor
